@@ -368,7 +368,7 @@ def normalise_data(adata, reCalSF=True, method='ExpAllC', copy=False):
     
     adata.X = np.log1p(adata.X/adata.obs['sf_gene'][:,None])
     if 'ERCC' in adata.obsm_keys():
-        if not adata.obsm['ERCC'].empty:
+        if adata.obsm['ERCC'].size !=0:
             adata.obsm['ERCC_norm'] = np.log1p(adata.obsm['ERCC']/adata.obs['sf_ercc'][:,None])
     if copy:
         return adata.copy()
@@ -1290,7 +1290,7 @@ def pathway_score_cal(adata, DBcont, minGS=5, maxGS=500):
         pathway = lcont[0]
         DBGenes = [x.upper() for x in lcont[2:]]
         DBGenes = np.in1d(TotalGenes, DBGenes)
-        if ((np.sum(DBGenes) < minGS) or (np.sum(DBGenes) > maxGS)): 
+        if ((np.sum(DBGenes) < minGS) & (np.sum(DBGenes) > maxGS)): 
             next
         else:
             Exp = np.mean(adata.raw[:, DBGenes].X, axis=1)
